;;; Zone file for distorted.org.uk

(load "hosts.lisp" :verbose nil)

;;;--------------------------------------------------------------------------
;;; Other definitions.

(setf *default-zone-admin* "hostmaster@distorted.org.uk")

(setf *default-zone-source* 'radius.distorted.org.uk.)

;;;--------------------------------------------------------------------------
;;; Main zone definition.

(defzone distorted.org.uk

  ;; Nameservers.
  :ns #+view/inside ((radius.ns :ip radius)
		     (vampire.ns :ip vampire))
      #-view/inside ((radius.ns :ip radius)
		     (vampire.ns :ip vampire)
		     (mythic-beasts-1.ns :ip mythic-ns1)
		     (mythic-beasts-2.ns :ip mythic-ns2)
		     (chiark.ns :ip chiark.greenend.org.uk))

  ;; Mail servers.
  ((@ mail lists bugs cryptomail)
   :mx mail
   :srv ((:smtp mail)))

  ;; Kerberos.
  (_kerberos :txt "DISTORTED.ORG.UK")
  :srv (((:kerberos :protocol :udp) krb)
	((:kerberos-master :protocol :udp :port 88) krb)
	(:kerberos-adm krb)
	((:kpasswd :protocol :udp) krb))

  ;; Other services.
  :srv ((:http www)
	(:ftp ftp))

  ;; Entry is via little router box.
  (dmz :net dmz)
  (guvnor (inside :svc gate.dmz) (dmz :a guvnor.dmz))
  (anon (dmz :a anon.dmz))
  (gate (dmz :a gate.dmz))
  (nat (dmz :a nat.dmz))

  ;; Wireless gateway.
  (wireless :net wireless)
  (evolution (safe :a evolution.safe))
  (evolution :alias evo)

  ;; Local services.
  :svc vampire
  ((www krb ftp rsync wiki git git-master
    bugs mail db i2p rawk vox www-cache)
   :svc vampire)

  ;; Internal services.
  #+view/inside ((ntp) :svc ibanez.unsafe)
  #+view/inside ((wpad ntp1 news lpr) :svc vampire.unsafe)

  ;; Anonymity services.
  (tor :svc #+view/inside vampire.unsafe
	    #-view/inside anon.dmz)

  ;; Colocated hosts.
  (colo :net colo)
  (jump :net jump)
  (fender ;(colo :a fender.colo)
	  (jump :a fender.jump))
  (precision ;(colo :a precision.colo)
	     (jump :a precision.jump))
  (telecaster ;(colo :a telecaster.colo)
	      (jump :a telecaster.jump))
  (telecaster :alias tele)
  (stratocaster ;(colo :a stratocaster.colo)
		(jump :a stratocaster.jump))
  (stratocaster :alias strat)
  (jazz ;(colo :a jazz.colo)
	(jump :a jazz.jump))

  ;; Wired ethernet.
  (unsafe :net unsafe)
  (safe :net safe)
  (untrusted :net untrusted)
  (vampire (unsafe :a vampire.unsafe)
	   (dmz :a vampire.dmz)
	   (safe :a vampire.safe)
	   (untrusted :a vampire.untrusted)
	   (iodine :a vampire.iodine))
  (ibanez (unsafe :a ibanez.unsafe)
	  (dmz :a ibanez.dmz))
  (radius (unsafe :a radius.unsafe)
	  (dmz :a radius.dmz)
	  (safe :a radius.safe)
	  (untrusted :a radius.untrusted))
  (roadstar (unsafe :a roadstar.unsafe)
	    (dmz :a roadstar.dmz))
  (jem (unsafe :a jem.unsafe)
       (dmz :a jem.dmz))
  (artist (unsafe :a artist.unsafe)
	  (dmz :a artist.dmz))

  ;; DHCP hosts.
  (gibson :cname gibson.dhcp)
  (lespaul :cname lespaul.dhcp)
  (firebird :cname firebird.dhcp)
  (marauder :cname marauder.dhcp)
  (invader :cname invader.dhcp)

  ;; Virtual network.
  (vpn :net vpn)
  (crybaby (vpn :a crybaby.vpn))
  (terror (vpn :a terror.vpn))
  (iodine :net iodine)

  ;; ITS.
  (its :net its)
  (gw (its :a gw.its))
  (mz (its :a mz.its))

  ;; Delegations.
  #+view/inside (dhcp :ns (radius.ns vampire.ns))
  (io :ns ((ns.io :ip vampire))))

;;;--------------------------------------------------------------------------
;;; Other subsidiary zones.

(defrevzone trusted
  :ns ((radius.ns :ip radius)
       (vampire.ns :ip vampire))
  :reverse unsafe
  :reverse vpn
  :reverse colo
  :reverse its
  (dhcp :ns (radius.ns vampire.ns))
  :cidr-delegation
  (trusted ((dhcp safe) 199.29.172.dhcp.199.29.172.in-addr.arpa)))

(defrevzone dmz
  :ns ((radius.ns :ip radius)
       (vampire.ns :ip vampire))
  :reverse dmz)

(defrevzone jump
  :ns ((radius.ns :ip radius)
       (vampire.ns :ip vampire))
  :reverse jump)

(defzone io.distorted.org.uk
  :ns ((ns :ip vampire))
  (about :txt "Fake zone used for IP-over-DNS tunnelling."))

;;;----- That's all, folks --------------------------------------------------
